@@ -144,7 +144,8 @@ void annoy_user_with_details_with_cont (const gchar *text,
 					package_info *pi, detail_kind kind,
 					void (*cont) (void *data), void *data);
 void annoy_user_with_log (const gchar *text);
-void annoy_user_with_errno (int err, const gchar *detail);
+void annoy_user_with_errno (int err, const gchar *detail,
+			    void (*cont) (void *), void *data);
 void annoy_user_with_gnome_vfs_result (GnomeVFSResult result,
 				       const gchar *detail);
 
@@ -343,8 +344,8 @@ void select_package_list (GList *package_list,
   SIZE_STRING_GENERAL uses less space than SIZE_STRING_DETAILED.
 */
 
-void size_string_general (char *buf, size_t n, int bytes);
-void size_string_detailed (char *buf, size_t n, int bytes);
+void size_string_general (char *buf, size_t n, int64_t bytes);
+void size_string_detailed (char *buf, size_t n, int64_t bytes);
 
 /* SHOW_DEB_FILE_CHOOSER shows a file chooser dialog for choosing a
    .deb file.  CONT is called with the selected URI, or NULL when
@@ -422,12 +423,6 @@ const char *skip_whitespace (const char *str);
  */
 bool all_whitespace (const char *str);
 
-/* NULL and empty strings are considered equal.  Whitespace at the
-   beginning and end is ignored.  Sequences of whitespaces are equal
-   to each other.
-*/
-bool tokens_equal (const char *str1, const char *str2);
-
 /* ENSURE_NETWORK requests an internet connection and calls CONT when
    it has been established or when the attempt failed.  SUCCESS
    reflects whether the connection could be established.
@@ -486,4 +481,8 @@ void respond_on_escape (GtkDialog *dialog, int response);
 */
 void grab_focus_on_map (GtkWidget *widget);
 
+/* Get the number of free bytes in the root filesystem.
+ */
+int64_t get_free_space ();
+
 #endif /* !UTIL_H */
